#[non_exhaustive]pub enum Ipv4RangeError {
InvalidFormat,
InvalidIpAddr,
InvalidRange,
}Available on crate feature
net only.Expand description
Error type for IPv4 range parsing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidFormat
Invalid range format
The input string is not in the correct range format. Expected format: “start-end” (e.g., “192.168.1.0-192.168.1.255”).
InvalidIpAddr
Invalid IP address
One of the IP addresses in the range is invalid.
InvalidRange
Invalid range
The start address is greater than the end address.